#include <hidef.h>      /* common defines and macros */
#include <mc9s12c128.h>     /* derivative information */
#pragma LINK_INFO DERIVATIVE "mc9s12c128"

#include "lcd_lib.h"
#include "modclock.h"
#include <stdio.h>
#define RESPONSE_MAX_LEN 16
#define QUERY_MAX_LEN RESPONSE_MAX_LEN

void doSerialComm( void );
void serialSetup( void );

char groupString[] = "TEST OK";
char msgBuf[RESPONSE_MAX_LEN+1];

void main(void) {
  EnableInterrupts;
  RDRT = 0;
  MODRR = 0;
  DDRT = 0xFF;
  DDRA = 0xFF;
  ATDDIEN = 0xFF;
  PTAD = 0;
  RDRAD = 0;
  PERAD = 0;
  
  clockSetup();
  serialSetup();
  lcdSetup();
  doSerialComm();
  
  for(;;) {
  } /* wait forever */
  /* please make sure that you never leave this function */
}


void serialSetup() {
 SCIBDH = 0x00;
 SCIBDL = 0x34;
 SCICR1 = 0x00;
 SCICR2 = 0x0C;
}

void doSerialComm( void ) {
  char query[QUERY_MAX_LEN+1];  //string to hold query value;
  char response[RESPONSE_MAX_LEN+1]; //string to hold response value
  char i;   //counter
  int errFlag;  //to hold return values
  
  //display group string, the CRC, and the current baud rate:
  errFlag = sprintf(msgBuf, "%s OK", groupString);
  lcdSimpleWrite(msgBuf);

  i=0;
  while(groupString[i] != 0) {
    query[i] = groupString[i]; 
    i++;
  }
  query[i++] = 0x4A; //checksum
  query[i++] = 0; //null terminator
  i = -1;
  do
  { while (! (SCISR1 & 0x80)) { } 
    i++;
    SCIDRL = query[i]; 
    SCISR1  = SCISR1 & 0x7F; //clear TDRE
  } while (query[i]);
  for (i=0;i<RESPONSE_MAX_LEN;i++) {
    while (! (SCISR1 & 0x20)) { } 
    response[i] = SCIDRL;
    if (response[i] == 0) {
      break; 
    }
  }
  response[i-1] = 0;
  errFlag = sprintf(msgBuf, "%s", response);   
  lcdSimpleWrite(msgBuf);  
  
}



